==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/PrintScaleType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p416162_="https://jakarta.ee/xml/ns/jaxb" xmlns:p761379_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p931522_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the page&#13;
 *                     &lt;ul&gt;&lt;li&gt;scaling mode for printouts of the document. (This setting is only a dialog default and can be changed by the user at any time).&lt;/li&gt;&lt;li&gt;readerDefault = Use the scaling functions provided by the display program.&lt;/li&gt;&lt;li&gt;noPrintScaling = Do no page scaling and print the pages in original size.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PrintScaleType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="PrintScaleType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="readerDefault"/>
 *     <enumeration value="noPrintScaling"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "PrintScaleType")
@XmlEnum
public enum PrintScaleType {

    @XmlEnumValue("readerDefault")
    READER_DEFAULT("readerDefault"),
    @XmlEnumValue("noPrintScaling")
    NO_PRINT_SCALING("noPrintScaling");
    private final String value;

    PrintScaleType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static PrintScaleType fromValue(String v) {
        for (PrintScaleType c: PrintScaleType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/PrintScaleType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p112675_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p263167_="https://jakarta.ee/xml/ns/jaxb" xmlns:p878401_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects the page&#13;
 *                     &lt;ul&gt;&lt;li&gt;scaling mode for printouts of the document. (This setting is only a dialog default and can be changed by the user at any time).&lt;/li&gt;&lt;li&gt;readerDefault = Use the scaling functions provided by the display program.&lt;/li&gt;&lt;li&gt;noPrintScaling = Do no page scaling and print the pages in original size.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PrintScaleType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="PrintScaleType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="readerDefault"/>
 *     <enumeration value="noPrintScaling"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "PrintScaleType")
@XmlEnum
public enum PrintScaleType {

    @XmlEnumValue("readerDefault")
    READER_DEFAULT("readerDefault"),
    @XmlEnumValue("noPrintScaling")
    NO_PRINT_SCALING("noPrintScaling");
    private final String value;

    PrintScaleType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static PrintScaleType fromValue(String v) {
        for (PrintScaleType c: PrintScaleType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
